@@ -1,4 +1,3 @@
-// drgeo-filter-chooser.h
 // Copyright (C)  2004  Pino Toscano <toscano.pino@tiscali.it>
 // Copyright (C)  2002  Dominique Devriese <devriese@kde.org>
 
@@ -14,8 +13,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #ifndef DRGEOFILTERCHOOSER_H
 #define DRGEOFILTERCHOOSER_H
@@ -31,7 +30,7 @@ class KigFilterDrgeoChooser
   Q_OBJECT
 
 public:
-  KigFilterDrgeoChooser( QStringList& l );
+  KigFilterDrgeoChooser( const QStringList& l );
   ~KigFilterDrgeoChooser();
 public slots:
   void slotOKPressed();
