@@ -14,7 +14,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
  USA
 **/
 
@@ -34,14 +34,7 @@
 #include <kdebug.h>
 #include <kglobal.h>
 #include <klocale.h>
-#include <kmessagebox.h>
 #include <knumvalidator.h>
-#include <kdeversion.h>
-#if KDE_IS_VERSION( 3, 1, 90 )
-#include <kinputdialog.h>
-#else
-#include <klineeditdlg.h>
-#endif
 
 #include <string>
 #include <math.h>
@@ -316,7 +309,13 @@ void EuclideanCoords::drawGrid( KigPainter& p, bool showgrid, bool showaxes ) co
 
 QString EuclideanCoords::coordinateFormatNotice() const
 {
-  return i18n( "Enter coordinates in the following form: \"x;y\",\n"
+  return i18n( "Enter coordinates in the following format: \"x;y\",\n"
+               "where x is the x coordinate, and y is the y coordinate." );
+}
+
+QString EuclideanCoords::coordinateFormatNoticeMarkup() const
+{
+  return i18n( "Enter coordinates in the following format: <b>\"x;y\"</b>, "
                "where x is the x coordinate, and y is the y coordinate." );
 }
 
@@ -358,7 +357,14 @@ QString PolarCoords::fromScreen( const Coordinate& pt, const KigDocument& d ) co
 QString PolarCoords::coordinateFormatNotice() const
 {
   // \xCE\xB8 is utf8 for the greek theta sign..
-  return i18n( "Enter coordinates in the following form: \"r; \xCE\xB8°\",\n"
+  return i18n( "Enter coordinates in the following format: \"r; \xCE\xB8°\",\n"
+               "where r and \xCE\xB8 are the polar coordinates." );
+}
+
+QString PolarCoords::coordinateFormatNoticeMarkup() const
+{
+  // \xCE\xB8 is utf8 for the greek theta sign..
+  return i18n( "Enter coordinates in the following format: <b>\"r; \xCE\xB8°\"</b>, "
                "where r and \xCE\xB8 are the polar coordinates." );
 }
 
@@ -507,35 +513,6 @@ QValidator* PolarCoords::coordinateValidator() const
   return new CoordinateValidator( true );
 }
 
-const Coordinate CoordinateSystem::getCoordFromUser( const QString& caption,
-                                                     const QString& label,
-                                                     const KigDocument& doc,
-                                                     QWidget* parent, bool* ok,
-                                                     const Coordinate* cvalue ) const
-{
-  bool done = false;
-  Coordinate ret;
-  QString value = cvalue ? fromScreen( *cvalue, doc ) : QString::null;
-  while ( ! done )
-  {
-    QValidator* vtor = coordinateValidator();
-#if KDE_IS_VERSION( 3, 1, 90 )
-    value = KInputDialog::getText( caption, label, value, ok, parent, 0, vtor );
-#else
-    value = KLineEditDlg::getText( caption, label, value, ok, parent, vtor );
-#endif
-    delete vtor;
-
-    if ( ! *ok ) return Coordinate();
-
-    ret = toScreen( value, *ok );
-    if ( *ok ) done = true;
-    else
-      KMessageBox::sorry( parent, i18n( "The coordinates you entered was not valid. Please try again.") );
-  };
-  return ret;
-}
-
 QStringList CoordinateSystemFactory::names()
 {
   QStringList ret;
