@@ -14,7 +14,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
  USA
 **/
 
@@ -43,10 +43,12 @@ class KigDocument;
 class ObjectHolder;
 
 /**
- * KigPainter is an extended qpainter...
- * currently the only difference is that it translates coordinates
+ * KigPainter is an extended QPainter.
+ *
+ * Currently the only difference is that it translates coordinates
  * from and to the internal coordinates/ the widget coordinates...
- * it calls KigWidget::appendOverlay() for all of the places it draws in...
+ *
+ * It calls KigWidget::appendOverlay() for all of the places it draws in...
  */
 class KigPainter
   : public Qt
@@ -80,7 +82,9 @@ public:
               bool needOverlay = true );
   ~KigPainter();
 
-  // what rect are we drawing on ?
+  /**
+   * what rect are we drawing on ?
+   */
   Rect window();
 
   QPoint toScreen( const Coordinate p ) const;
@@ -92,16 +96,17 @@ public:
   // colors and stuff...
   void setStyle( const PenStyle c );
   void setColor( const QColor& c );
-  void setWidth( const int c ); // setting this to -1 means to use
-                                 // the default width for the object
-                                 // being drawn..  a point -> 5, other
-                                 // objects -> 1
+  /**
+   * setting this to -1 means to use the default width for the object
+   * being drawn..  a point -> 5, other objects -> 1
+   */
+  void setWidth( const int c );
   void setPointStyle( const int p );
   void setPen( const QPen& p );
   void setBrushStyle( const BrushStyle c );
   void setBrush( const QBrush& b );
   void setBrushColor( const QColor& c );
-  
+
   QColor getColor() const;
   bool getNightVision( ) const;
 
@@ -154,12 +159,12 @@ public:
    */
   void drawRect( const QRect& r );
 
-  /*
+  /**
    * draw a circle...
    */
   void drawCircle( const Coordinate& center, const double radius );
 
-  /*
+  /**
    * draw a segment...
    */
   void drawSegment ( const Coordinate& from, const Coordinate& to );
@@ -186,7 +191,7 @@ public:
   /**
    * draw a thick point..  This is what the user sees when he draws a
    * point.  In fact it isn't a point, but a filled circle of a
-   * certain @param radius...
+   * certain radius...
    */
   void drawFatPoint( const Coordinate& p );
 
@@ -223,9 +228,9 @@ public:
 
   void drawVector( const Coordinate& a, const Coordinate& b );
 
-  /*
+  /**
    * draw text...
-   * @see QPainter::drawText()
+   * \see QPainter::drawText()
    */
   void drawText( const Rect r, const QString s, int textFlags = 0,
                  int len = -1);
@@ -251,7 +256,7 @@ protected:
   /**
    * adds a number of rects to mOverlay so that the rects entirely
    * contain the circle...
-   * @see mOverlay
+   * \see mOverlay
    */
   void circleOverlay( const Coordinate& centre, double radius );
   // this works recursively...
@@ -260,7 +265,7 @@ protected:
   /**
    * adds some rects to mOverlay, so that they cover the segment p1p2
    * completely...
-   * @see Object::getOverlay()
+   * \see Object::getOverlay()
    */
   void segmentOverlay( const Coordinate& p1, const Coordinate& p2 );
 
@@ -271,11 +276,13 @@ protected:
 
   /**
    * ...
-   * @see drawText(), QPainter::boundingRect()
+   * \see drawText(), QPainter::boundingRect()
    */
   void textOverlay( const QRect& r, const QString s, int textFlags, int len );
 
-  // the size we want the overlay rects to be...
+  /**
+   * the size we want the overlay rects to be...
+   */
   double overlayRectSize();
 
   std::vector<QRect> mOverlay;
