@@ -12,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #ifndef KIG_MODE_BASE_MODE_H
 #define KIG_MODE_BASE_MODE_H
@@ -43,6 +43,9 @@ class BaseMode
 
 protected:
   void enableActions();
+
+  std::vector<ObjectHolder*> oco();
+  QPoint pointLocation();
 protected:
 
   virtual void dragRect( const QPoint& p, KigWidget& w );
