@@ -12,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "conic_imp.h"
 
@@ -100,15 +100,15 @@ const char* ConicImp::iconForProperty( uint which ) const
   if ( which < Parent::numberOfProperties() )
     return Parent::iconForProperty( which );
   if ( which == Parent::numberOfProperties() + pnum++ )
-    return "text"; // conic type string
+    return "kig_text"; // conic type string
   else if ( which == Parent::numberOfProperties() + pnum++ )
     return ""; // focus1
   else if ( which == Parent::numberOfProperties() + pnum++ )
     return ""; // focus2
   else if ( which == Parent::numberOfProperties() + pnum++ )
-    return "text"; // cartesian equation string
+    return "kig_text"; // cartesian equation string
   else if ( which == Parent::numberOfProperties() + pnum++ )
-    return "text"; // polar equation string
+    return "kig_text"; // polar equation string
   else assert( false );
   return "";
 }
