@@ -1,4 +1,3 @@
-// point_imp.cc
 // Copyright (C)  2002  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -13,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "point_imp.h"
 
@@ -32,6 +31,12 @@ PointImp::PointImp( const Coordinate& c )
 {
 }
 
+Coordinate PointImp::attachPoint() const
+{
+  return mc;
+//  return Coordinate::invalidCoord();
+}
+
 void PointImp::draw( KigPainter& p ) const
 {
   p.drawFatPoint( mc );
@@ -105,7 +110,7 @@ ObjectImp* PointImp::property( uint which, const KigDocument& d ) const
     return new DoubleImp( mc.x );
   if ( which == Parent::numberOfProperties() + 2 )
     return new DoubleImp( mc.y );
-  else assert( false );
+//  else assert( false );
   return new InvalidImp;
 }
 
@@ -182,3 +187,37 @@ Rect PointImp::surroundingRect() const
 {
   return Rect( mc, 0., 0. );
 }
+
+/*
+ */
+
+BogusPointImp::BogusPointImp( const Coordinate& c )
+  : PointImp( c )
+{
+}
+
+BogusPointImp::~BogusPointImp()
+{
+}
+
+const ObjectImpType* BogusPointImp::stype()
+{
+  static const ObjectImpType t(
+    0, "boguspoint",
+    "SHOULDNOTBESEEN",
+    "SHOULDNOTBESEEN",
+    "SHOULDNOTBESEEN",
+    "SHOULDNOTBESEEN",
+    "SHOULDNOTBESEEN",
+    "SHOULDNOTBESEEN",
+    "SHOULDNOTBESEEN",
+    "SHOULDNOTBESEEN",
+    "SHOULDNOTBESEEN"
+    );
+  return &t;
+}
+
+const ObjectImpType* BogusPointImp::type() const
+{
+  return BogusPointImp::stype();
+}
