@@ -117,7 +117,7 @@ FITSViewer::FITSViewer (const KURL *url, QWidget *parent, const char *name)
     statusBar()->setItemFixed(1, 100);
     statusBar()->insertItem("", 2);
     statusBar()->setItemFixed(2, 100);
-    statusBar()->insertItem(i18n("Welcome to KStars FITS Editor."), 3, 1, true);
+    statusBar()->insertItem(i18n("Welcome to KStars FITS Viewer"), 3, 1, true);
     statusBar()->setItemAlignment(3 , Qt::AlignLeft);
     
     /* FITS initializations */
@@ -213,9 +213,7 @@ void FITSViewer::slotClose()
     
   QString caption = i18n( "Save Changes to FITS?" );
 		QString message = i18n( "The current FITS file has unsaved changes.  Would you like to save before closing it?" );
-		QString ybut = KStdGuiItem::save().text();
-		QString nbut = i18n( "&Discard" );
-		int ans = KMessageBox::warningYesNoCancel( 0, message, caption, ybut, nbut );
+		int ans = KMessageBox::warningYesNoCancel( 0, message, caption, KStdGuiItem::save(), KStdGuiItem::discard() );
 		if ( ans == KMessageBox::Yes )
 			fileSave();	
 		else if ( ans == KMessageBox::No ) 
@@ -234,9 +232,7 @@ void FITSViewer::closeEvent(QCloseEvent *ev)
     
   QString caption = i18n( "Save Changes to FITS?" );
 		QString message = i18n( "The current FITS file has unsaved changes.  Would you like to save before closing it?" );
-		QString ybut = KStdGuiItem::save().text();
-		QString nbut = i18n( "&Discard" );
-		int ans = KMessageBox::warningYesNoCancel( 0, message, caption, ybut, nbut );
+		int ans = KMessageBox::warningYesNoCancel( 0, message, caption, KStdGuiItem::save(), KStdGuiItem::discard() );
 		if ( ans == KMessageBox::Yes )
 			fileSave();	
 		else if ( ans == KMessageBox::No ) 
@@ -379,7 +375,7 @@ float * FITSViewer::loadData(const char *filename, float *buffer)
 
 void FITSViewer::calculateStats()
 {
-  kdDebug() << "Calculating statistics..." << endl;
+  /*kdDebug() << "Calculating statistics..." << endl;*/
   stats.min 	= min(stats.minAt);
   stats.max 	= max(stats.maxAt);
   stats.average = average();
@@ -388,9 +384,9 @@ void FITSViewer::calculateStats()
   stats.width   = image->width;
   stats.height  = image->height;
   
-  kdDebug() << "Min: " << stats.min << " - Max: " << stats.max << endl;
+  /*kdDebug() << "Min: " << stats.min << " - Max: " << stats.max << endl;
   kdDebug() << "Average: " << stats.average << " - stddev: " << stats.stddev << endl;
-  kdDebug() << "Width: " << stats.width << " - Height " << stats.height << " - bitpix " << stats.bitpix << endl;
+  kdDebug() << "Width: " << stats.width << " - Height " << stats.height << " - bitpix " << stats.bitpix << endl;*/
   
   statusBar()->changeItem( QString("%1 x %2").arg( (int) stats.width).arg( (int) stats.height), 2);
 
@@ -502,9 +498,7 @@ void FITSViewer::fileOpen()
     
   QString caption = i18n( "Save Changes to FITS?" );
 		QString message = i18n( "The current FITS file has unsaved changes.  Would you like to save before closing it?" );
-		QString ybut = KStdGuiItem::save().text();
-		QString nbut = i18n( "&Discard" );
-		int ans = KMessageBox::warningYesNoCancel( 0, message, caption, ybut, nbut );
+		int ans = KMessageBox::warningYesNoCancel( 0, message, caption, KStdGuiItem::save(), KStdGuiItem::discard() );
 		if ( ans == KMessageBox::Yes )
 			fileSave();	
 		else if ( ans == KMessageBox::No ) 
