@@ -46,7 +46,6 @@ class GeoLocation;
 class FindDialog;
 class LocationDialog;
 class TimeDialog;
-class ViewOpsDialog;
 class InfoBoxes;
 class ToggleAction;
 class TimeStepBox;
@@ -56,12 +55,11 @@ class INDIMenu;
 class INDIDriver;
 class imagesequence;
 
-/**@class KStars
-	*This is the main window for KStars.  It is derived from KMainWindow.
+/**
+	*@class KStars
+	*@short This is the main window for KStars.
 	*In addition to the GUI elements, the class contains the program clock,
-	*KStarsData, and SkyMap objects.
-	*It also contains functions for the DCOP interface.
-	*@short KStars base class
+	*KStarsData, and SkyMap objects.  It also contains functions for the DCOP interface.
 	*@author Jason Harris
 	*@version 1.0
 	*/
@@ -71,15 +69,14 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 
   Q_OBJECT
   public:
-	/**Constructor.
-		*@param kstarsData the KStars Data object
-		*/
-		KStars( KStarsData* kstarsData );
-
-	/**Constructor.
+	/**
+		*@short Constructor.
 		*@param doSplash should the splash panel be displayed during
 		*initialization.
 		*@param startClockRunning should the clock be running on startup?
+		*@param startDateString date (in string representation) to start running from.
+		*
+		* @todo Refer to documentation on date format.
 		*/
 		KStars( bool doSplash, bool startClockRunning = true, const QString &startDateString = "" );
 
@@ -109,11 +106,11 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 		*/
 		InfoBoxes* infoBoxes();
 
-	/**@returns pointer to the INDI driver
+	/**@return pointer to the INDI driver
 		*/
 		INDIDriver* getINDIDriver(void) { return indidriver; }
 
-	/**@returns pointer to the INDI menu
+	/**@return pointer to the INDI menu
 		*/
 		INDIMenu* getINDIMenu(void) { return indimenu; }
 
@@ -127,139 +124,292 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 		*/
 		void addColorMenuItem( QString name, QString actionName );
 
+	/**Remove an item from the color-scheme action manu
+		*@param actionName The internal name of the action (derived from filename)
+		*/
 		void removeColorMenuItem( QString actionName );
 
-	/**DCOP interface function.  Set focus to given Ra/Dec coordinates */
+	/**DCOP interface function.  
+		*Set focus to given Ra/Dec coordinates 
+		*@p ra the Right Ascension coordinate for the focus (in Hours)
+		*@p dec the Declination coordinate for the focus (in Degrees)
+		*/
 		ASYNC setRaDec( double ra, double dec );
 
-	/**DCOP interface function.  Set focus to given Alt/Az coordinates. */
+	/**DCOP interface function.  
+		*Set focus to given Alt/Az coordinates. 
+		*@p alt the Altitude coordinate for the focus (in Degrees)
+		*@p az the Azimuth coordinate for the focus (in Degrees)
+		*/
 		ASYNC setAltAz(double alt, double az);
 
 	/**DCOP interface function.
-		*Point in the direction described by the string argument.  */
+		*Point in the direction described by the string argument.  
+		*@p direction either an object name, a compass direction (e.g., "north"), or "zenith"
+		*/
 		ASYNC lookTowards( const QString direction );
 
-	/**DCOP interface function.  Zoom in. */
+	/**DCOP interface function.  Zoom in one step. */
 		ASYNC zoomIn(void) { slotZoomIn(); };
 
-	/**DCOP interface function.  Zoom out. */
+	/**DCOP interface function.  Zoom out one step. */
 		ASYNC zoomOut(void){ slotZoomOut(); };
 
-	/**DCOP interface function.  Default Zoom. */
+	/**DCOP interface function.  reset to the default zoom level. */
 		ASYNC defaultZoom(void) { slotDefaultZoom(); }
 
-	/**DCOP interface function.  Set ZoomLevel manually. */
-		ASYNC zoom(double);
+	/**DCOP interface function.  Set zoom level to specified value. 
+		*@p a the zoom level.  Units are pixels per radian.
+		*/
+		ASYNC zoom(double z);
 
-	/**DCOP interface function.  Set local time and date. */
+	/**DCOP interface function.  Set local time and date. 
+		*@p yr year of date
+		*@p mth month of date
+		*@p day day of date
+		*@p hr hour of time
+		*@p min minute of time
+		*@p sec second of time
+		*/
 		ASYNC setLocalTime(int yr, int mth, int day, int hr, int min, int sec);
 
-	/**DCOP interface function.  Pause for t seconds. */
+	/**DCOP interface function.  Delay further execution of DCOP commands. 
+		*@p t number of seconds to delay
+		*/
 		ASYNC waitFor( double t );
 
-	/**DCOP interface function.  Pause until Key k is pressed. */
+	/**DCOP interface function.  Pause further DCOP execution until a key is pressed. 
+		*@p k the key which will resume DCOP execution
+		*/
 		ASYNC waitForKey( const QString k );
 
-	/**DCOP interface function.  Toggle tracking. */
+	/**DCOP interface function.  Toggle tracking. 
+		*@p track engage tracking if true; else disengage tracking
+		*/
 		ASYNC setTracking( bool track );
 
-	/**DCOP interface function.  modify option. */
+	/**DCOP interface function.  modify a view option. 
+		*@p option the name of the option to be modified
+		*@p value the option's new value
+		*/
 		ASYNC changeViewOption( const QString option, const QString value );
 
-	/**DCOP interface function.  Show text message in a popup window. */
+	/**DCOP interface function.
+		*@p name the name of the option to query
+		*@return the current value of the named option
+		*/
+		QString getOption( const QString &name );
+
+	/**DCOP interface function.  Read config file. 
+		*This function is useful for restoring the user settings from the config file, 
+		*after having modified the settings in memory.
+		*@sa writeConfig()
+		*/
+		ASYNC readConfig();
+
+	/**DCOP interface function.  Write current settings to config file. 
+		*This function is useful for storing user settings before modifying them with a DCOP
+		*script.  The original settings can be restored with readConfig().
+		*@sa readConfig()
+		*/
+		ASYNC writeConfig();
+
+	/**DCOP interface function.  Show text message in a popup window. 
+		*@note Not Yet Implemented
+		*@p x x-coordinate for message window
+		*@p y y-coordinate for message window
+		*@p message the text to display in the message window
+		*/
 		ASYNC popupMessage( int x, int y, const QString message );
 
-	/**DCOP interface function.  Draw a line on the sky. */
+	/**DCOP interface function.  Draw a line on the sky map. 
+		*@note Not Yet Implemented
+		*@p x1 starting x-coordinate of line
+		*@p y1 starting y-coordinate of line
+		*@p x2 ending x-coordinate of line
+		*@p y2 ending y-coordinate of line
+		*@p speed speed at which line should appear from start to end points (in pixels per second)
+		*/
 		ASYNC drawLine( int x1, int y1, int x2, int y2, int speed );
 
-	/**DCOP interface function.  Set the geographic location. */
+	/**DCOP interface function.  Set the geographic location. 
+		*@p city the city name of the location
+		*@p province the province name of the location
+		*@p country the country name of the location
+		*/
 		ASYNC setGeoLocation( const QString city, const QString province, const QString country );
 
-	/**DCOP interface function.  Set a color. */
+	/**DCOP interface function.  Modify a color. 
+		*@p colorName the name of the color to be modified (e.g., "SkyColor")
+		*@p value the new color to use
+		*/
 		ASYNC setColor( const QString colorName, const QString value );
 
-	/**DCOP interface function.  Load a color scheme. */
+	/**DCOP interface function.  Load a color scheme. 
+		*@p name the name of the color scheme to load (e.g., "Moonless Night")
+		*/
 		ASYNC loadColorScheme( const QString name );
 
-	/**DCOP interface function.  Export the sky image to a file. */
+	/**DCOP interface function.  Export the sky image to a file. 
+		*@p filename the filename for the exported image
+		*@p width the width for the exported image
+		*@p height the height for the exported image
+		*/
 		ASYNC exportImage( const QString filename, int width, int height );
 
-	/**DCOP interface function.  Print the sky image. */
+	/**DCOP interface function.  Print the sky image. 
+		*@p usePrintDialog if true, the KDE print dialog will be shown; otherwise, default parameters will be used
+		*@p useChartColors if true, the "Star Chart" color scheme will be used for the printout, which will save ink.
+		*/
 		ASYNC printImage( bool usePrintDialog, bool useChartColors );
 		
-	/**DCOP interface function.  Establish an INDI driver. */
-	        ASYNC startINDI (QString driverName, bool useLocal);
+	/**DCOP interface function.  Establish an INDI driver. 
+		*@p driverName the name of the driver to be established
+		*@p useLocal establish driver locally?
+		*/
+		ASYNC startINDI (QString driverName, bool useLocal);
 		
-	/**DCOP interface function. Shutdown an INDI driver. */
-	        ASYNC shutdownINDI (QString driverName);
+	/**DCOP interface function. Shutdown an INDI driver. 
+		*@p driverName the name of the driver to be shut down
+		*/
+		ASYNC shutdownINDI (QString driverName);
 		
-	/**DCOP interface function.  Turn INDI driver on/off. */
+	/**DCOP interface function.  Turn INDI driver on/off. 
+		*@p driverName the name of the driver to be switched on/off
+		*@p turnOn if true, turn driver on; otherwise turn off
+		*/
 		ASYNC switchINDI(QString driverName, bool turnOn);
 	
-	/**DCOP interface function.  Set INDI connection port. */
+	/**DCOP interface function.  Set INDI connection port. 
+		*@p driverName the name of the driver for which the port will be set
+		*@p port the port identifier
+		*/
 		ASYNC setINDIPort(QString driverName, QString port);
 	
-	/**DCOP interface function.  Set INDI target RA/DEC. */
+	/**DCOP interface function.  Set INDI target RA/DEC coordinates
+		*@p driverName the name of the driver 
+		*@p RA the target's Right Ascension coordinate (in Hours) 
+		*@p DEC the target's Declination coordinate (in Degrees) 
+		*/
 		ASYNC setINDITargetCoord(QString driverName, double RA, double DEC);
 	
-	/**DCOP interface function.  Set INDI target RA/DEC. */
+	/**DCOP interface function.  Set INDI target to a named object. 
+		*@p driverName the name of the driver 
+		*@p objectName the name of the object to be targeted
+		*/
 		ASYNC setINDITargetName(QString driverName, QString objectName);
 	
-	/**DCOP interface function.  Set INDI target by name lookup. */
+	/**DCOP interface function.  Set INDI action. 
+		*@p driverName the name of the driver 
+		*@p action the action to set
+		*/
 		ASYNC setINDIAction(QString driverName, QString action);
 	
-	/**DCOP interface function.  Set INDI target by name lookup. */
+	/**DCOP interface function.  Pause DCOP execution until named INDI action is completed. 
+		*@p driverName the name of the driver 
+		*@p action the action which is to be completed before resuming DCOP execution
+		*/
 		ASYNC waitForINDIAction(QString driverName, QString action);
 	
-	/**DCOP interface function.  Set INDI focus speed. */
-		ASYNC setINDIFocusSpeed(QString driverName, QString action);
+	/**DCOP interface function.  Set INDI focus speed. 
+		*@p driverName the name of the driver 
+		*@p action the name of the action (??)
+		*/
+		ASYNC setINDIFocusSpeed(QString driverName,unsigned int speed);
 	
-	/**DCOP interface function.  Set INDI focus direction and focus. */
+	/**DCOP interface function.  Set INDI focus direction and focus. 
+		*@p driverName the name of the driver 
+		*@p focusDir 0 = focus in; 1 = focus out
+		*/
 		ASYNC startINDIFocus(QString driverName, int focusDir);
 	
-	/**DCOP interface function.  Set INDI geographical information. */
+	/**DCOP interface function.  Set INDI geographical information. 
+		*@p driverName the name of the driver 
+		*@p longitude the longitude to set, in Degrees
+		*@p latitude the latitude to set, in Degrees
+		*/
 		ASYNC setINDIGeoLocation(QString driverName, double longitude, double latitude);
 	
-	/**DCOP interface function.  Sets focus operation timeout. */
+	/**DCOP interface function.  Sets focus operation timeout. 
+		*@p driverName the name of the driver 
+		*@p timeout the timeout interval, in seconds (?)
+		*/
 		ASYNC setINDIFocusTimeout(QString driverName, int timeout);
 	
-	/**DCOP interface function.  Start camera exposure with a timeout. */
+	/**DCOP interface function.  Start camera exposure with a timeout. 
+		*@p driverName the name of the driver 
+		*@p timeout the exposure time, in seconds (?)
+		*/
 		ASYNC startINDIExposure(QString driverName, int timeout);
 		
-	/**DCOP interface function.  Set INDI UTC date and time. */
+	/**DCOP interface function.  Set INDI UTC date and time. 
+		*@p driverName the name of the driver 
+		*@p UTCDateTime the UTC date and time (e.g., "23 June 2004 12:30:00" ?)
+		*/
 		ASYNC setINDIUTC(QString driverName, QString UTCDateTime);
 	
-	/**DCOP interface function. Set INDI Telescope action. */
+	/**DCOP interface function. Set INDI Telescope action. 
+		*@p deviceName the name of the telescope device 
+		*@p action the action to set
+		*/
 		ASYNC setINDIScopeAction(QString deviceName, QString action);
 		
-	/**DCOP interface function. Set CCD camera frame type. */
+	/**DCOP interface function. Set CCD camera frame type. 
+		*@p deviceName the name of the CCD device 
+		*@p type the frame type
+		*/
 		ASYNC setINDIFrameType(QString deviceName, QString type);
 		
-	/**DCOP interface function. Set CCD target temperature. */
+	/**DCOP interface function. Set CCD filter. 
+		*@p deviceName the name of the CCD device 
+		*@p filter_num identifier of the CCD filter
+		*/
+		ASYNC setINDIFilterNum(QString deviceName, int filter_num);
+
+	/**DCOP interface function. Set CCD target temperature. 
+		*@p deviceName the name of the CCD device 
+		*@p temp the target CCD temperature (in Celsius ?)
+		*/
 		ASYNC setINDICCDTemp(QString deviceName, int temp);
 		
+
+	/**@short Apply config options throughout the program.
+		*In most cases, options are set in the "Options" object directly, 
+		*but for some things we have to manually react to config changes.
+		*/
+		void applyConfig();
+
 	public slots:
 		/**
 			*Update time-dependent data and (possibly) repaint the sky map.
+			*@p automaticDSTchange change DST status automatically?
 			*/
 		void updateTime( const bool automaticDSTchange = true );
 
 		/**
 			*Apply new settings and redraw skymap
 			*/
-		void slotApplySettings( void );
+		void slotApplyConfigChanges( void );
 
 		/**
-			*Zoom in
+			*action slot: Zoom in one step
 			*/
 		void slotZoomIn();
 
 		/**
-			*Zoom out
+			*action slot: Zoom out one step
 			*/
 		void slotZoomOut();
 
+		/**
+			*action slot: Set the zoom level to its default value
+			*/
 		void slotDefaultZoom();
+
+		/**
+			*action slot: Allow user to specify a field-of-view angle for the display window in degrees, 
+			*and set the zoom level accordingly.
+			*/
 		void slotSetZoom();
 
 	/**
@@ -272,18 +422,24 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 		*/
 		void slotGeoLocator();
 
-		/* Delete FindDialog because ObjNames list has changed in KStarsData due to
+	/**Delete FindDialog because ObjNames list has changed in KStarsData due to
 		*reloading star data. So list in FindDialog must be new filled with current data.
 		*/
 		void clearCachedFindDialog();
 
+	/**
+		*Resume execution of DCOP commands
+		*/
 		void resumeDCOP( void ) { kapp->dcopClient()->resume(); }
 
+	/**
+		*Remove all trails which may have been added to solar system bodies
+		*/
 		void slotClearAllTrails();
 
 	private slots:
 		/**
-			*action slot: synch kstars clock to system time
+			*action slot: sync kstars clock to system time
 			*/
 		void slotSetTimeToNow();
 
@@ -336,6 +492,12 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 		 */
 		 void slotWUT();
 
+//FIXME GLOSSARY
+//		 /**
+//		  * action slot: open the glossary
+//		  */
+//		 void slotGlossary();
+
 		/**
 		 * action slot: open ScriptBuilder dialog
 		 */
@@ -356,6 +518,11 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 		 */
 		void slotTelescopeWizard();
 
+		/**
+		 * action slot: open Telescope wizard
+		 */
+		void slotTelescopeProperties();
+
 		/**
 		 * action slot: open Image Sequence dialog
 		 */
@@ -421,12 +588,13 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 		/**Select the Target symbol (a.k.a. field-of-view indicator) */
 		void slotTargetSymbol();
 
+		/**Invoke the Field-of-View symbol editor window */
 		void slotFOVEdit();
 
 		/**Toggle between Equatorial and Ecliptic coordinte systems */
 		void slotCoordSys();
 
-  /** Toggle display of the observing list */
+		/**Toggle display of the observing list tool*/
 		void slotObsList();
 
 		/**Meta-slot to handle display toggles for all of the viewtoolbar buttons.
@@ -446,10 +614,13 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 
 	private:
 		/**
-			*Initialize Menu bar.
+			*Initialize Menu bar, toolbars and all Actions.
 			*/
 		void initActions();
 
+		/**
+			*Initialize Field-of-View symbols and FOV submenu
+			*/
 		void initFOV();
 
 		/**
@@ -496,10 +667,13 @@ class KStars::privatedata {
 		KStarsSplash *splash;
 		KStarsData *kstarsData;
 
+		/**Constructor */
 		privatedata(KStars *parent) : ks(parent), splash(0), kstarsData(0) {};
-		void buildGUI();
-
+		/**Destructor */
 		~privatedata();
+
+		/**Build the main KStars window */
+		void buildGUI();
 };
 
 #endif
