@@ -40,6 +40,7 @@
 #include "infoboxes.h"
 #include "simclock.h"
 #include "csegment.h"
+#include "customcatalog.h"
 #include "devicemanager.h"
 #include "indimenu.h"
 #include "indiproperty.h"
@@ -51,12 +52,13 @@ void SkyMap::drawOverlays( QPixmap *pm ) {
 		QPainter p;
 		p.begin( pm );
 
-		infoBoxes()->focusCoordChanged( focus() );
+		showFocusCoords( true );
 		drawBoxes( p );
 
 		//draw FOV symbol
 		ksw->data()->fovSymbol.draw( p, (float)(Options::fOVSize() * Options::zoomFactor()/57.3/60.0) );
 		drawTelescopeSymbols( p );
+		drawObservingList( p );
 		drawZoomBox( p );
 		if ( transientObject() ) drawTransientLabel( p );
 		if (isAngleMode()) {
@@ -83,24 +85,12 @@ void SkyMap::drawTransientLabel( QPainter &p ) {
 	if ( transientObject() ) {
 		p.setPen( TransientColor );
 
-		QFont stdFont( p.font() );
-		QFont smallFont( stdFont );
-		smallFont.setPointSize( stdFont.pointSize() - 2 );
-		if ( Options::zoomFactor() < 10.*MINZOOM ) {
-			p.setFont( smallFont );
-		} else {
-			p.setFont( stdFont );
-		}
-
 		if ( checkVisibility( transientObject(), fov(), XRange ) ) {
 			QPoint o = getXY( transientObject(), Options::useAltAz(), Options::useRefraction(), 1.0 );
 			if ( o.x() >= 0 && o.x() <= width() && o.y() >= 0 && o.y() <= height() ) {
 				drawNameLabel( p, transientObject(), o.x(), o.y(), 1.0 );
 			}
 		}
-
-		//reset font
-		p.setFont( stdFont );
 	}
 }
 
@@ -113,6 +103,33 @@ void SkyMap::drawBoxes( QPainter &p ) {
 	}
 }
 
+void SkyMap::drawObservingList( QPainter &psky, double scale ) {
+	psky.setPen( QPen( QColor( data->colorScheme()->colorNamed( "ObsListColor" ) ), 1 ) );
+
+	if ( ksw && ksw->observingList()->count() ) {
+		for ( SkyObject* obj = ksw->observingList()->first(); obj; obj = ksw->observingList()->next() ) {
+			
+			if ( checkVisibility( obj, fov(), XRange ) ) {
+				QPoint o = getXY( obj, Options::useAltAz(), Options::useRefraction() );
+
+				// label object if it is currently on screen
+				if (o.x() >= 0 && o.x() <= width() && o.y() >=0 && o.y() <= height() ) {
+					if ( Options::obsListSymbol() ) {
+						int size = int(20*scale);
+						int x1 = o.x() - size/2;
+						int y1 = o.y() - size/2;
+						psky.drawArc( x1, y1, size, size, -60*16, 120*16 );
+						psky.drawArc( x1, y1, size, size, 120*16, 120*16 );
+					}
+					if ( Options::obsListText() ) {
+						drawNameLabel( psky, obj, o.x(), o.y(), scale );
+					}
+				}
+			}
+		}
+	}
+}
+
 void SkyMap::drawTelescopeSymbols(QPainter &psky) {
 
 	if ( ksw ) { //ksw doesn't exist in non-GUI mode!
@@ -120,7 +137,8 @@ void SkyMap::drawTelescopeSymbols(QPainter &psky) {
 		INDI_P *portConnect;
 		INDI_E *lp;
 		INDIMenu *devMenu = ksw->getINDIMenu();
-		bool useJ2000 = false;
+		bool useJ2000 (false), useAltAz(false);
+		SkyPoint indi_sp;
 
 		if (!Options::indiCrosshairs() || devMenu == NULL)
 			return;
@@ -134,6 +152,9 @@ void SkyMap::drawTelescopeSymbols(QPainter &psky) {
 		{
 			for (uint j=0; j < devMenu->mgr.at(i)->indi_dev.count(); j++)
 			{
+				useAltAz = false;
+				useJ2000 = false;
+
 				// make sure the dev is on first
 				if (devMenu->mgr.at(i)->indi_dev.at(j)->isOn())
 				{
@@ -150,13 +171,42 @@ void SkyMap::drawTelescopeSymbols(QPainter &psky) {
 					if (eqNum == NULL)
 					{
 						eqNum = devMenu->mgr.at(i)->indi_dev.at(j)->findProp("EQUATORIAL_COORD");
-						if (eqNum) useJ2000 = true;
+						if (eqNum == NULL)
+                                                {
+						  eqNum = devMenu->mgr.at(i)->indi_dev.at(j)->findProp("HORIZONTAL_COORD");
+                                                  if (eqNum == NULL) continue;
+                                                  else
+							useAltAz = true;
+						}
+                                                else
+						 useJ2000 = true;
 					}
 
 					// make sure it has RA and DEC properties
 					if ( eqNum)
 					{
 						//fprintf(stderr, "Looking for RA label\n");
+                                                if (useAltAz)
+						{
+						lp = eqNum->findElement("AZ");
+						if (!lp)
+							continue;
+
+						dms azDMS(lp->value);
+						
+						lp = eqNum->findElement("ALT");
+						if (!lp)
+							continue;
+
+						dms altDMS(lp->value);
+
+						indi_sp.setAz(azDMS);
+						indi_sp.setAlt(altDMS);
+
+						}
+						else
+						{
+
 						lp = eqNum->findElement("RA");
 						if (!lp)
 							continue;
@@ -175,14 +225,21 @@ void SkyMap::drawTelescopeSymbols(QPainter &psky) {
 						//kdDebug() << "the KStars RA is " << raDMS.toHMSString() << endl;
 						//kdDebug() << "the KStars DEC is " << decDMS.toDMSString() << "\n****************" << endl;
 
-						SkyPoint sp( &raDMS, &decDMS);
-						
-						if (useJ2000)
-							sp.apparentCoord( (double) J2000, ksw->data()->ut().djd());
-							
-						sp.EquatorialToHorizontal( ksw->LST(), ksw->geo()->lat() );
+						indi_sp.setRA(raDMS);
+						indi_sp.setDec(decDMS);
 
-						QPoint P = getXY( &sp, Options::useAltAz(), Options::useRefraction() );
+						if (useJ2000)
+						{
+							indi_sp.setRA0(raDMS);
+							indi_sp.setDec0(decDMS);
+							indi_sp.apparentCoord( (double) J2000, ksw->data()->ut().djd());
+						}
+							
+						if ( Options::useAltAz() ) indi_sp.EquatorialToHorizontal( ksw->LST(), ksw->geo()->lat() );
+
+						}
+
+						QPoint P = getXY( &indi_sp, Options::useAltAz(), Options::useRefraction() );
 
 						int s1 = pxperdegree/2;
 						int s2 = pxperdegree;
@@ -202,7 +259,6 @@ void SkyMap::drawTelescopeSymbols(QPainter &psky) {
 						psky.drawEllipse( x1, y1, s1, s1 );
 						psky.drawEllipse( x2, y2, s2, s2 );
 
-						//FIXME the label is not displayed optimally (needs to be somewhat centered vertically)
 						psky.drawText( x0+s2 + 2 , y0, QString(devMenu->mgr.at(i)->indi_dev.at(j)->label) );
 
 					}
@@ -666,7 +722,7 @@ void SkyMap::drawEcliptic( QPainter& psky, double scale )
 	}
 }
 
-void SkyMap::drawHorizon( QPainter& psky, QFont& stdFont, double scale )
+void SkyMap::drawHorizon( QPainter& psky, double scale )
 {
 	int Width = int( scale * width() );
 	int Height = int( scale * height() );
@@ -860,7 +916,6 @@ void SkyMap::drawHorizon( QPainter& psky, QFont& stdFont, double scale )
 //	Draw compass heading labels along horizon
 				SkyPoint *c = new SkyPoint;
 				QPoint cpoint;
-				psky.setFont( stdFont );
 
 				if ( Options::showGround() )
 					psky.setPen( QColor ( data->colorScheme()->colorNamed( "CompassColor" ) ) );
@@ -1104,12 +1159,11 @@ void SkyMap::drawConstellationBoundaries( QPainter &psky, double scale ) {
 	}
 }
 
-void SkyMap::drawConstellationNames( QPainter& psky, QFont& stdFont, double scale ) {
+void SkyMap::drawConstellationNames( QPainter& psky, double scale ) {
 	int Width = int( scale * width() );
 	int Height = int( scale * height() );
 
 	//Draw Constellation Names
-	psky.setFont( stdFont );
 	psky.setPen( QColor( data->colorScheme()->colorNamed( "CNameColor" ) ) );
 	for ( SkyObject *p = data->cnameList.first(); p; p = data->cnameList.next() ) {
 		if ( checkVisibility( p, fov(), XRange ) ) {
@@ -1168,12 +1222,26 @@ void SkyMap::drawStars( QPainter& psky, double scale ) {
 						curStar->draw( psky, sky, spixmap, o.x(), o.y(), true, scale );
 
 						// now that we have drawn the star, we can display some extra info
+						//don't label unnamed stars with the generic "star" name
+						bool drawName = ( Options::showStarNames() && (curStar->name() != i18n("star") ) );
 						if ( !checkSlewing && (curStar->mag() <= Options::magLimitDrawStarInfo() )
-								&& ( Options::showStarNames() || Options::showStarMagnitudes() ) ) {
+								&& ( drawName || Options::showStarMagnitudes() ) ) {
 
 							psky.setPen( QColor( data->colorScheme()->colorNamed( "SNameColor" ) ) );
+							QFont stdFont( psky.font() );
+							QFont smallFont( stdFont );
+							smallFont.setPointSize( stdFont.pointSize() - 2 );
+							if ( Options::zoomFactor() < 10.*MINZOOM ) {
+								psky.setFont( smallFont );
+							} else {
+								psky.setFont( stdFont );
+							}
+
 							curStar->drawLabel( psky, o.x(), o.y(), Options::zoomFactor(),
-									Options::showStarNames(), Options::showStarMagnitudes(), scale );
+									drawName, Options::showStarMagnitudes(), scale );
+
+							//reset font
+							psky.setFont( stdFont );
 						}
 					}
 				}
@@ -1214,7 +1282,7 @@ void SkyMap::drawDeepSkyCatalog( QPainter& psky, QPtrList<DeepSkyObject>& catalo
 					QPoint o = getXY( obj, Options::useAltAz(), Options::useRefraction(), scale );
 					if ( o.x() >= 0 && o.x() <= Width && o.y() >= 0 && o.y() <= Height ) {
 						//PA for Deep-Sky objects is 90 + PA because major axis is horizontal at PA=0
-						double PositionAngle = 90. + findPA( obj, o.x(), o.y(), scale );
+						double PositionAngle = 90. - findPA( obj, o.x(), o.y(), scale );
 
 						//Draw Image
 						if ( drawImage && Options::zoomFactor() > 5.*MINZOOM ) {
@@ -1297,15 +1365,11 @@ void SkyMap::drawDeepSkyObjects( QPainter& psky, double scale )
 	}
 
 	//Draw Custom Catalogs
-	for ( register unsigned int i=0; i<Options::catalogCount(); ++i ) { //loop over custom catalogs
+	for ( register unsigned int i=0; i<data->CustomCatalogs.count(); ++i ) { 
 		if ( Options::showCatalog()[i] ) {
+			QPtrList<SkyObject> cat = data->CustomCatalogs.at(i)->objList();
 
-			psky.setBrush( NoBrush );
-			psky.setPen( QColor( data->colorScheme()->colorNamed( "NGCColor" ) ) );
-
-			QPtrList<DeepSkyObject> cat = data->CustomCatalogs[ Options::catalogName()[i] ];
-
-			for ( DeepSkyObject *obj = cat.first(); obj; obj = cat.next() ) {
+			for ( SkyObject *obj = cat.first(); obj; obj = cat.next() ) {
 
 				if ( checkVisibility( obj, fov(), XRange ) ) {
 					QPoint o = getXY( obj, Options::useAltAz(), Options::useRefraction(), scale );
@@ -1319,16 +1383,21 @@ void SkyMap::drawDeepSkyObjects( QPainter& psky, double scale )
 							float sizeFactor = 2.0;
 							int size = int( sizeFactor*(zoomlim - mag) ) + 1;
 							if (size>23) size=23;
-							if ( size ) {
+							if ( size > 0 ) {
 								QChar c = starobj->color();
 								QPixmap *spixmap = starpix->getPixmap( &c, size );
 								starobj->draw( psky, sky, spixmap, o.x(), o.y(), true, scale );
 							}
 						} else {
 							//PA for Deep-Sky objects is 90 + PA because major axis is horizontal at PA=0
-							double pa = 90. + findPA( obj, o.x(), o.y(), scale );
-							obj->drawImage( psky, o.x(), o.y(), pa, Options::zoomFactor() );
-							obj->drawSymbol( psky, o.x(), o.y(), pa, Options::zoomFactor() );
+							DeepSkyObject *dso = (DeepSkyObject*)obj;
+							double pa = 90. + findPA( dso, o.x(), o.y(), scale );
+							dso->drawImage( psky, o.x(), o.y(), pa, Options::zoomFactor() );
+
+							psky.setBrush( NoBrush );
+							psky.setPen( QColor( data->CustomCatalogs.at(i)->color() ) );
+
+							dso->drawSymbol( psky, o.x(), o.y(), pa, Options::zoomFactor() );
 						}
 					}
 				}
@@ -1403,9 +1472,19 @@ void SkyMap::drawAttachedLabels( QPainter &psky, double scale ) {
 void SkyMap::drawNameLabel( QPainter &psky, SkyObject *obj, int x, int y, double scale ) {
 	int size(0);
 
+	QFont stdFont( psky.font() );
+	QFont smallFont( stdFont );
+	smallFont.setPointSize( stdFont.pointSize() - 2 );
+	if ( Options::zoomFactor() < 10.*MINZOOM ) {
+		psky.setFont( smallFont );
+	} else {
+		psky.setFont( stdFont );
+	}
+
 	//Stars
 	if ( obj->type() == SkyObject::STAR ) {
 		((StarObject*)obj)->drawLabel( psky, x, y, Options::zoomFactor(), true, false, scale );
+		psky.setFont( stdFont );
 		return;
 
 	//Solar system
@@ -1434,6 +1513,9 @@ void SkyMap::drawNameLabel( QPainter &psky, SkyObject *obj, int x, int y, double
 
 	int offset = int( ( 0.5*size + 4 ) );
 	psky.drawText( x+offset, y+offset, obj->translatedName() );
+
+	//Reset font
+	psky.setFont( stdFont );
 }
 
 void SkyMap::drawPlanetTrail( QPainter& psky, KSPlanetBase *ksp, double scale )
@@ -1776,32 +1858,22 @@ void SkyMap::exportSkyImage( const QPaintDevice *pd ) {
 
 	if ( x1 || y1 ) p.translate( x1, y1 );
 
-	QFont stdFont = p.font();
-	QFont smallFont = p.font();
-	smallFont.setPointSize( stdFont.pointSize() - 2 );
-
 	if ( drawMW ) drawMilkyWay( p, scale );
 	if ( drawGrid ) drawCoordinateGrid( p, scale );
 
 	if ( drawCBounds ) drawConstellationBoundaries( p, scale );
 	if ( drawCLines ) drawConstellationLines( p, scale );
-	if ( drawCNames ) drawConstellationNames( p, stdFont, scale );
+	if ( drawCNames ) drawConstellationNames( p, scale );
 
 	if ( Options::showEquator() ) drawEquator( p, scale );
 	if ( Options::showEcliptic() ) drawEcliptic( p, scale );
 
-	// stars and planets use the same font size
-	if ( Options::zoomFactor() < 10.*MINZOOM ) {
-		p.setFont( smallFont );
-	} else {
-		p.setFont( stdFont );
-	}
-
 	drawStars( p, scale );
 	drawDeepSkyObjects( p, scale );
 	drawSolarSystem( p, drawPlanets, scale );
 	drawAttachedLabels( p, scale );
-	drawHorizon( p, stdFont, scale );
+	drawObservingList( p, scale );
+	drawHorizon( p, scale );
 
 	p.end();
 }
