@@ -13,7 +13,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 // This file is originally written by Walter Scheppers, but allmost
@@ -906,9 +906,9 @@ TreeNode* Parser::Learn()
 	}
 	func->appendChild(idList);
 
-	func->appendChild( Block() ); // do the Block() thing
+	learnedFunctionList.append( func->getLook() ); // publish the function
 
-	learnedFunctionList.append( func->getLook() );
+	func->appendChild( Block() );
 
 	return func;
 }
